@@ -49,6 +49,7 @@
 
 package com.openexchange.saml.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -115,6 +116,7 @@ import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import com.openexchange.ajax.LoginServlet;
+import com.openexchange.ajax.SessionUtility;
 import com.openexchange.ajax.fields.LoginFields;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
@@ -258,7 +260,7 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
 
             Assertion bearerAssertion = validationResult.getBearerAssertion();
             AuthenticationInfo authInfo = backend.resolveAuthnResponse(response, bearerAssertion, requestInfo);
-            LOG.debug("User {} in context {} is considered authenticated", authInfo.getUserId(), authInfo.getContextId());
+            LOG.debug("User {} in context {} is considered authenticated", I(authInfo.getUserId()), I(authInfo.getContextId()));
 
             enhanceAuthInfo(authInfo, bearerAssertion);
             Map<String, String> properties = authInfo.getProperties();
@@ -277,7 +279,8 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
                 .setHost(requestInfo.getDomainName())
                 .setPath(getRedirectPathPrefix() + "login")
                 .setParameter(LoginServlet.PARAMETER_ACTION, SAMLLoginTools.ACTION_SAML_LOGIN + getPathString(backend.getPath()))
-                .setParameter(SAMLLoginTools.PARAM_TOKEN, sessionToken);
+                .setParameter(SAMLLoginTools.PARAM_TOKEN, sessionToken)
+                .setParameter(SAMLLoginTools.PARAM_SHARD, SessionUtility.getShardCookieValue());
 
             String loginPath = requestInfo.getLoginPath();
             if (loginPath != null) {
@@ -523,7 +526,7 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
         spssoDescriptor.addSupportedProtocol(SAMLConstants.SAML20P_NS);
 
         AssertionConsumerService acs = openSAML.buildSAMLObject(AssertionConsumerService.class);
-        acs.setIndex(1);
+        acs.setIndex(I(1));
         acs.setIsDefault(Boolean.TRUE);
         acs.setBinding(SAMLConstants.SAML2_POST_BINDING_URI);
         acs.setLocation(config.getAssertionConsumerServiceURL());
@@ -633,11 +636,11 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
                     throw SAMLExceptionCode.UNMARSHALLING_ERROR.create("Not a valid BaseID or NameID: " + subjectID);
                 }
             } catch (ClassCastException e) {
-                throw SAMLExceptionCode.UNMARSHALLING_ERROR.create(subjectID);
+                throw SAMLExceptionCode.UNMARSHALLING_ERROR.create(e, subjectID);
             } catch (XMLParserException e) {
-                throw SAMLExceptionCode.UNMARSHALLING_ERROR.create(subjectID);
+                throw SAMLExceptionCode.UNMARSHALLING_ERROR.create(e, subjectID);
             } catch (UnmarshallingException e) {
-                throw SAMLExceptionCode.UNMARSHALLING_ERROR.create(subjectID);
+                throw SAMLExceptionCode.UNMARSHALLING_ERROR.create(e, subjectID);
             }
         }
 
@@ -713,7 +716,7 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
 
     private void sendLogoutResponseViaPOST(String responseXML, HttpServletRequest httpRequest, HttpServletResponse httpResponse) throws IOException {
         try {
-            String encoded = Base64.encodeBase64String(responseXML.getBytes());
+            String encoded = Base64.encodeBase64String(responseXML.getBytes(com.openexchange.java.Charsets.UTF_8));
             TemplateService templateService = services.getService(TemplateService.class);
             OXTemplate template = templateService.loadTemplate(config.getLogoutResponseTemplate());
             Map<String, String> vars = new HashMap<String, String>(5);
@@ -757,7 +760,7 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
             }
 
             Collection<String> sessionIds = sessiondService.removeSessionsGlobally(SessionFilter.create(filterString));
-            LOG.debug("Removed {} sessions for {} indexes", sessionIds.size(), numIndexes);
+            LOG.debug("Removed {} sessions for {} indexes", I(sessionIds.size()), I(numIndexes));
             removedAnySession = sessionIds.size() > 0;
         } else {
             int contextId = logoutInfo.getContextId();
@@ -765,7 +768,7 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
             if (contextId > 0 && userId > 0) {
                 sessiondService.removeUserSessionsGlobally(userId, contextId);
                 removedAnySession = true;
-                LOG.debug("Removed sessions globally for user {} in context {}", userId, contextId);
+                LOG.debug("Removed sessions globally for user {} in context {}", I(userId), I(contextId));
             } else {
                 LOG.warn("LogoutRequest contained no session indexes but no valid user and context were determined. Cannot invalidate any session...");
             }
@@ -1004,9 +1007,8 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
             if (binding == Binding.HTTP_REDIRECT) {
                 // bytes are deflated in redirect binding
                 return openSAML.getParserPool().parse(new InflaterInputStream(new ByteArrayInputStream(requestBytes), new Inflater(true)));
-            } else {
-                return openSAML.getParserPool().parse(new ByteArrayInputStream(requestBytes));
             }
+            return openSAML.getParserPool().parse(new ByteArrayInputStream(requestBytes));
         } catch (XMLParserException e) {
             throw SAMLExceptionCode.DECODING_ERROR.create(e, e.getMessage());
         }
@@ -1056,9 +1058,8 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
             if (binding == Binding.HTTP_REDIRECT) {
                 // bytes are deflated in redirect binding
                 return openSAML.getParserPool().parse(new InflaterInputStream(new ByteArrayInputStream(requestBytes), new Inflater(true)));
-            } else {
-                return openSAML.getParserPool().parse(new ByteArrayInputStream(requestBytes));
             }
+            return openSAML.getParserPool().parse(new ByteArrayInputStream(requestBytes));
         } catch (XMLParserException e) {
             throw SAMLExceptionCode.DECODING_ERROR.create(e, e.getMessage());
         }
